@@ -1,5 +1,5 @@
 /*
- * $Id: abook.c,v 1.19 2001/10/05 11:50:11 jheinonen Exp $
+ * $Id: abook.c,v 1.23 2002/02/04 13:41:25 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -419,13 +419,13 @@ abook_fopen (const char *path, const char *mode)
 {	
 	struct stat s;
 	
-	if( ! strchr(mode, 'r') )
-		return fopen(path, mode);
-	
 	if ( (stat(path, &s)) == -1 )
 		return NULL;
-	
-	return S_ISREG(s.st_mode) ? fopen(path, mode) : NULL;
+
+	if(strchr(mode, 'r'))
+		return S_ISREG(s.st_mode) ? fopen(path, mode) : NULL;
+	else
+		return S_ISDIR(s.st_mode) ? NULL : fopen(path, mode);
 }
 
 
@@ -456,22 +456,27 @@ convert(char *srcformat, char *srcfile, char *dstformat, char *dstfile)
 
 	switch( import(srcformat, srcfile) ) {
 		case -1:
-			printf("input format %s not supported\n", srcformat);
+			fprintf(stderr,
+				"input format %s not supported\n", srcformat);
 			ret = 1;
+			break;
 		case 1:
-			printf("cannot read file %s\n", srcfile);
+			fprintf(stderr, "cannot read file %s\n", srcfile);
 			ret = 1;
+			break;
 	}
 
 	if(!ret)
 		switch( export(dstformat, dstfile) ) {
 			case -1:
-				printf("output format %s not supported\n",
-						dstformat);
+				fprintf(stderr,
+					"output format %s not supported\n",
+					dstformat);
 				ret = 1;
 				break;
 			case 1:
-				printf("cannot write file %s\n", dstfile);
+				fprintf(stderr,
+					"cannot write file %s\n", dstfile);
 				ret = 1;
 				break;
 		}
@@ -503,6 +508,12 @@ quit_add_email()
 	exit(0);
 }
 
+static void
+quit_add_email_sig(int signal)
+{
+	quit_add_email();
+}
+
 static void
 init_add_email()
 {
@@ -518,7 +529,7 @@ init_add_email()
 
 	atexit(close_database);
 
-	signal(SIGINT, quit_add_email);
+	signal(SIGINT, quit_add_email_sig);
 }
 
 static int
@@ -562,14 +573,19 @@ add_email(int quiet)
 {
 	char *line;
 	char *name = NULL, *email = NULL;
-	
+	struct stat s;	
+
+	if( (fstat(fileno(stdin), &s)) == -1 || S_ISDIR(s.st_mode)) {
+		fprintf(stderr, "stdin is a directory or cannot stat stdin\n");
+		exit(1);
+	}
+
 	init_add_email();
 
 	do {
 		line = getaline(stdin);
 		if(line && !strncasecmp("From:", line, 5) ) {
 			getname(line, &name, &email);
-			my_free(line);
 			add_email_count += add_email_add_item(quiet,
 					name, email);
 			my_free(name);
