@@ -1,6 +1,6 @@
 
 /*
- * $Id: filter.c,v 1.14 2001/10/12 09:31:44 jheinonen Exp $
+ * $Id: filter.c,v 1.15 2002/01/19 11:07:02 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -13,6 +13,7 @@
 #include <ctype.h>
 #include <pwd.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include "abook_curses.h"
 #include "filter.h"
 #include "abook.h"
@@ -219,7 +220,7 @@ i_read_file(char *filename, int (*func) (FILE *in))
 	FILE *in;
 	int ret = 0;
 
-	if( ( in = fopen( filename, "r" ) ) == NULL )
+	if( ( in = abook_fopen( filename, "r" ) ) == NULL )
 		return 1;
 
 	ret = (*func) (in);
@@ -248,9 +249,13 @@ import(char filtname[FILTNAME_LEN], char *filename)
 	if( i<0 )
 		return -1;
 
-	if( !strcmp(filename, "-") )
-		ret = (*i_filters[i].func) (stdin);
-	else
+	if( !strcmp(filename, "-") ) {
+		struct stat s;
+		if( (fstat(fileno(stdin), &s)) == -1 || S_ISDIR(s.st_mode))
+			ret = 1;
+		else
+			ret = (*i_filters[i].func) (stdin);
+	} else
 		ret =  i_read_file(filename, i_filters[i].func);
 	
 	if( tmp == items )
@@ -496,7 +501,7 @@ ldif_read_line(FILE *in)
 		free(line);
 	}
 
-	if( *buf == '#' ) {
+	if(buf && *buf == '#' ) {
 		free(buf);
 		return NULL;
 	}
@@ -797,7 +802,7 @@ html_export_database(FILE *out, struct db_enumerator e)
 			    tmp,
 			    database[e.item][NAME] );
 		else
-		    fprintf(out, "<tr>\n<td>%s>\n",
+		    fprintf(out, "<tr>\n<td>%s\n",
 			    database[e.item][NAME] );
 
 		fprintf(out, "<td>%s\n<td>%s\n",
